@@ -21,7 +21,7 @@ def main(
         "World", help="The name to say hi to.", autocompletion=complete_name
     )
 ):
-    typer.echo(f"Hello {name}")
+    print(f"Hello {name}")
 
 
 if __name__ == "__main__":
