@@ -12,7 +12,7 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] COMMAND [ARGS]..." in result.output
-    assert "Commands:" in result.output
+    assert "Commands" in result.output
     assert "items" in result.output
     assert "users" in result.output
 
@@ -21,7 +21,7 @@ def test_help_items():
     result = runner.invoke(app, ["items", "--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] COMMAND [ARGS]..." in result.output
-    assert "Commands:" in result.output
+    assert "Commands" in result.output
     assert "create" in result.output
     assert "delete" in result.output
     assert "sell" in result.output
@@ -49,7 +49,7 @@ def test_help_users():
     result = runner.invoke(app, ["users", "--help"])
     assert result.exit_code == 0
     assert "[OPTIONS] COMMAND [ARGS]..." in result.output
-    assert "Commands:" in result.output
+    assert "Commands" in result.output
     assert "create" in result.output
     assert "delete" in result.output
     assert "sell" not in result.output
